@@ -56,8 +56,13 @@ class JWTPayload:
 
 
 class AuthServerConnector:
+    _SERVER_NAME_HEADER = "server_name"
+
     Config = AbmServiceConnector.Config
-    Context = AbmServiceConnector.Context
+
+    @dataclass
+    class Context(AbmServiceConnector.Context):
+        server_name: str
 
     def __init__(self, config: Config, context: Context) -> None:
         self.config = config
@@ -65,6 +70,12 @@ class AuthServerConnector:
         self._connector = AbmServiceConnector(config, context)
         logger.info(f"{type(self).__name__} inited")
 
+    async def get_public_key(self) -> str:
+        return await self._connector.get(
+            path="v1/public_key/get",
+            headers={self._SERVER_NAME_HEADER: self.context.server_name},
+        )
+
     async def validate_access_token(self, token: str, origin: str) -> JWTPayload:
         answer = await self._connector.post(
             path="v1/access_token/validate",
